#!/bin/bash

mkdir -p /test
chown 2 /test
chmod 777 /test
